#
# spec file for package ghc-language-c
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name language-c
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.10.0
Release:        2.2
Summary:        Analysis and generation of C code
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  alex
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-pretty-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  happy
ExcludeArch:    %{ix86}

%description
Language C is a Haskell library for the analysis and generation of C code.
It features a complete, well tested parser and pretty printer for all of C99
and a large set of C11 and clang/GNU extensions.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc AUTHORS AUTHORS.c2hs ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Mar  1 2025 Peter Simons <psimons@suse.com>
- Update language-c to version 0.10.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Nov 17 2024 Peter Simons <psimons@suse.com>
- Update language-c to version 0.10.0.
  [#]# 0.10.0
  - Support for half-precision floating point `__fp16`, `_Float16`, and `_Float16x`.
  - Support for bfloat16 `__bf16`.
  - Support alignment specifier `_Alignas` in struct declatations.
* Fri Oct 18 2024 Peter Simons <psimons@suse.com>
- Update language-c to version 0.9.4.
  [#]# 0.9.4
  - Support `happy-2.1`.
* Sat Jan 20 2024 Peter Simons <psimons@suse.com>
- Update language-c to version 0.9.3.
  Upstream has renamed and modified the change log file(s) in this
  release. Unfortunately, the automatic updater cannot reliable
  determine relevant entries for this release.
* Tue Nov  7 2023 Peter Simons <psimons@suse.com>
- Update language-c to version 0.9.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Apr  6 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Jan 10 2023 Peter Simons <psimons@suse.com>
- Update language-c to version 0.9.2.
  [#]# 0.9.2
  - Add support for 128 bit builtin integer types
* Wed Apr  6 2022 Peter Simons <psimons@suse.com>
- Update language-c to version 0.9.1.
  [#]# 0.9.1
  - Support parsing an empty list of clobbers after a colon in `asm` statements
* Wed Mar 16 2022 Peter Simons <psimons@suse.com>
- Update language-c to version 0.9.0.2.
  [#]# 0.9.0.2
  - Correct lower bound on GHC
* Sat Feb  5 2022 Peter Simons <psimons@suse.com>
- Update language-c to version 0.9.0.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Dec 20 2020 psimons@suse.com
- Update language-c to version 0.9.0.1.
  [#]# 0.9.0.1
  - Scrap dependency on syb
  Thanks to @vmchale
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Sep  4 2020 psimons@suse.com
- Update language-c to version 0.9.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/language-c-0.9/src/ChangeLog
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add language-c at version 0.8.3.
